@@ -6,12 +6,11 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.17 22:00:00                  #
+# Updated Date: 2023.12.28 17:00:00                  #
 # ================================================== #
 
-import json
-import os
-import uuid
+from pygpt_net.item.attachment import AttachmentItem
+from pygpt_net.provider.attachment.json_file import JsonFileProvider
 
 
 class Attachments:
@@ -22,30 +21,30 @@ class Attachments:
         :param window: Window instance
         """
         self.window = window
-        self.config_file = 'attachments.json'
+        self.provider = JsonFileProvider(window)
         self.items = {}
         self.current = None
 
-    def create_id(self):
-        """
-        Create unique uuid
+    def install(self):
+        """Install provider data"""
+        self.provider.install()
 
-        :return: uuid
-        """
-        return str(uuid.uuid4())
+    def patch(self, app_version):
+        """Patch provider data"""
+        self.provider.patch(app_version)
 
-    def select(self, mode, file_id):
+    def select(self, mode, id):
         """
         Select attachment by uuid
 
         :param mode: mode
-        :param file_id: file_id
+        :param id: id
         """
         if mode not in self.items:
             self.items[mode] = {}
 
-        if file_id in self.items[mode]:
-            self.current = file_id
+        if id in self.items[mode]:
+            self.current = id
 
     def count(self, mode):
         """
@@ -71,7 +70,7 @@ class Attachments:
         if mode not in self.items:
             self.items[mode] = {}
 
-        return self.items[mode].keys()
+        return list(self.items[mode].keys())
 
     def get_id_by_idx(self, mode, idx):
         """
@@ -79,29 +78,29 @@ class Attachments:
 
         :param mode: mode
         :param idx: index
-        :return: uuid
+        :return: file ID
         :rtype: str or None
         """
         i = 0
-        for file_id in self.get_ids(mode):
+        for id in self.get_ids(mode):
             if i == idx:
-                return file_id
+                return id
             i += 1
 
-    def get_by_id(self, mode, file_id):
+    def get_by_id(self, mode, id):
         """
         Return attachment by ID
 
         :param mode: mode
-        :param file_id: file_id
+        :param id: file id
         :return: dict
         :rtype: dict
         """
         if mode not in self.items:
             self.items[mode] = {}
 
-        if file_id in self.items[mode]:
-            return self.items[mode][file_id]
+        if id in self.items[mode]:
+            return self.items[mode][id]
 
     def get_by_idx(self, mode, index):
         """
@@ -112,9 +111,9 @@ class Attachments:
         :return: context item
         :rtype: dict
         """
-        file_id = self.get_id_by_idx(mode, index)
-        if file_id is not None:
-            return self.items[mode][file_id]
+        id = self.get_id_by_idx(mode, index)
+        if id is not None:
+            return self.items[mode][id]
 
     def get_all(self, mode):
         """
@@ -129,52 +128,71 @@ class Attachments:
 
         return self.items[mode]
 
-    def delete(self, mode, file_id):
+    def new(self, mode, name=None, path=None, auto_save=True):
         """
-        Delete attachment by file_id
+        Create new attachment
 
         :param mode: mode
-        :param file_id: file_id
+        :param name: name
+        :param path: path
+        :param auto_save: auto_save
+        :return: AttachmentItem
+        :rtype: AttachmentsItem
+        """
+        attachment = self.create()
+        attachment.name = name
+        attachment.path = path
+
+        if mode not in self.items:
+            self.items[mode] = {}
+
+        self.items[mode][attachment.id] = attachment
+        self.current = attachment.id
+
+        if auto_save:
+            self.save()
+
+        return attachment
+
+    def build(self):
+        """
+        Build attachment
+
+        :return: AttachmentItem
+        :rtype: AttachmentItem
+        """
+        attachment = AttachmentItem()
+        attachment.name = None
+        attachment.path = None
+        return attachment
+
+    def create(self):
+        """
+        Create attachment item
+
+        :return: AttachmentItem
+        :rtype: AttachmentItem
+        """
+        attachment = self.build()
+        id = self.provider.create(attachment)
+        attachment.id = id
+        return attachment
+
+    def add(self, mode, item):
+        """
+        Add item to attachments
+
+        :param mode: mode
+        :param item: item to add
         """
         if mode not in self.items:
             self.items[mode] = {}
 
-        if file_id in self.items[mode]:
-            del self.items[mode][file_id]
-            self.save()
+        id = item.id
+        self.items[mode][id] = item  # add item to attachments
 
-    def delete_all(self, mode):
-        """
-        Delete all attachments
-
-        :param mode: mode
-        """
-        self.clear(mode)
-
-        # update index
-        path = os.path.join(self.window.config.path, self.config_file)
-        data = {'__meta__': self.window.config.append_meta(), 'items': {}}
-        try:
-            dump = json.dumps(data, indent=4)
-            with open(path, 'w', encoding="utf-8") as f:
-                f.write(dump)
-                f.close()
-        except Exception as e:
-            print(e)
-
-    def clear(self, mode):
-        """
-        Clear all attachments in mode
-
-        :param mode: mode
-        """
-        self.items[mode] = {}
-
-    def clear_all(self):
-        """
-        Clear all attachments
-        """
-        self.items = {}
+        # save attachments
+        self.save()
 
     def has(self, mode):
         """
@@ -189,49 +207,42 @@ class Attachments:
 
         return len(self.items[mode]) > 0
 
-    def new(self, mode, name=None, path=None, auto_save=True):
+    def delete(self, mode, id):
         """
-        Create new attachment
+        Delete attachment by file_id
 
         :param mode: mode
-        :param name: name
-        :param path: path
-        :param auto_save: auto_save
-        :return: created file ID
-        :rtype: str
+        :param id: file id
         """
-        file_id = self.create_id()  # create unique id
-        attachment = AttachmentItem()
-        attachment.id = file_id
-        attachment.name = name
-        attachment.path = path
-
         if mode not in self.items:
             self.items[mode] = {}
 
-        self.items[mode][file_id] = attachment
-        self.current = file_id
-
-        if auto_save:
+        if id in self.items[mode]:
+            del self.items[mode][id]
             self.save()
 
-        return attachment
-
-    def add(self, mode, item):
+    def delete_all(self, mode):
         """
-        Add item to attachments
+        Delete all attachments
 
         :param mode: mode
-        :param item: item to add
         """
-        if mode not in self.items:
-            self.items[mode] = {}
+        self.clear(mode)
+        self.provider.truncate(mode)
 
-        file_id = item.id
-        self.items[mode][file_id] = item  # add item to attachments
+    def clear(self, mode):
+        """
+        Clear all attachments in mode
 
-        # save to file
-        self.save()
+        :param mode: mode
+        """
+        self.items[mode] = {}
+
+    def clear_all(self):
+        """
+        Clear all attachments
+        """
+        self.items = {}
 
     def replace_id(self, mode, tmp_id, attachment):
         """
@@ -249,21 +260,38 @@ class Attachments:
             del self.items[mode][tmp_id]
             self.save()
 
-    def rename_file(self, mode, file_id, name):
+    def rename_file(self, mode, id, name):
         """
         Update name
 
         :param mode: mode
-        :param file_id: file_id
+        :param id: file id
         :param name: new name
         """
-        data = self.get_by_id(mode, file_id)
+        data = self.get_by_id(mode, id)
         data.name = name
         self.save()
 
+    def make_json_list(self, attachments):
+        """
+        Make json list
+
+        :param attachments: attachments
+        :return: json list
+        :rtype: dict
+        """
+        result = {}
+        for id in attachments:
+            attachment = attachments[id]
+            result[id] = {
+                'name': attachment.name,
+                'path': attachment.path
+            }
+        return result
+
     def from_files(self, mode, files):
         """
-        Load attachments from assistant files
+        Load current from assistant files
 
         :param mode: mode
         :param files: files
@@ -273,10 +301,12 @@ class Attachments:
             file = files[id]
             item = AttachmentItem()
             item.name = id
+
             if 'name' in file and file['name'] is not None and file['name'] != "":
                 item.name = file['name']
             if 'path' in file and file['path'] is not None and file['path'] != "":
                 item.path = file['path']
+
             item.id = id
             item.remote = id
             item.send = True
@@ -284,7 +314,7 @@ class Attachments:
 
     def from_attachments(self, mode, attachments):
         """
-        Load attachments from attachments
+        Load current from attachments
 
         :param mode: mode
         :param attachments: attachments
@@ -295,104 +325,9 @@ class Attachments:
             self.add(mode, attachment)
 
     def load(self):
-        """Load attachments from file"""
-        path = os.path.join(self.window.config.path, self.config_file)
-        try:
-            if os.path.exists(path):
-                with open(path, 'r', encoding="utf-8") as file:
-                    data = json.load(file)
-                    file.close()
-                    if data == "" or data is None or 'items' not in data:
-                        self.items = {}
-                        return
-                    # deserialize
-                    for mode in data['items']:
-                        self.items[mode] = {}
-                        for id in data['items'][mode]:
-                            attachment = data['items'][mode][id]
-                            item = AttachmentItem()
-                            item.deserialize(attachment)
-                            self.items[mode][id] = item
-        except Exception as e:
-            print(e)
-            self.items = {}
+        """Load attachments"""
+        self.items = self.provider.load()
 
     def save(self):
-        """
-        Save attachments to file
-        """
-        try:
-            # update attachments
-            path = os.path.join(self.window.config.path, self.config_file)
-            data = {}
-            items = {}
-
-            # serialize
-            for mode in self.items:
-                items[mode] = {}
-                for id in self.items[mode]:
-                    attachment = self.items[mode][id]
-                    items[mode][id] = attachment.serialize()
-
-            data['__meta__'] = self.window.config.append_meta()
-            data['items'] = items
-            dump = json.dumps(data, indent=4)
-            with open(path, 'w', encoding="utf-8") as f:
-                f.write(dump)
-                f.close()
-
-        except Exception as e:
-            print("Error while saving attachments: {}".format(str(e)))
-
-
-class AttachmentItem:
-    def __init__(self):
-        """
-        Attachment item
-        """
-        self.name = None
-        self.id = None
-        self.path = None
-        self.remote = None
-        self.send = False
-
-    def serialize(self):
-        """
-        Serialize item to dict
-
-        :return: serialized item
-        :rtype: dict
-        """
-        return {
-            'id': self.id,
-            'name': self.name,
-            'path': self.path,
-            'remote': self.remote,
-            'send': self.send
-        }
-
-    def deserialize(self, data):
-        """
-        Deserialize item from dict
-
-        :param data: serialized item
-        """
-        if 'id' in data:
-            self.id = data['id']
-        if 'name' in data:
-            self.name = data['name']
-        if 'path' in data:
-            self.path = data['path']
-        if 'remote_id' in data:
-            self.remote = data['remote']
-        if 'send' in data:
-            self.send = data['send']
-
-    def dump(self):
-        """
-        Dump item to string
-
-        :return: serialized item
-        :rtype: str
-        """
-        return json.dumps(self.serialize())
+        """Save attachments"""
+        self.provider.save(self.items)
