@@ -6,8 +6,9 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.17 22:00:00                  #
+# Updated Date: 2023.12.25 21:00:00                  #
 # ================================================== #
+
 import json
 
 
@@ -49,13 +50,13 @@ class Command:
         15) ALWAYS remember that any text content must appear at the beginning of your response and commands must only be included at the end.
         16) Try to run commands executed in the user's system in the background if running them may prevent receiving a response (e.g. when it is a desktop application)
         17) Every command param must be placed in one line, so when you generate code you must put all of code in one line
-        Commands list:
-        '''
+
+        Commands list:'''
 
         # get custom prompt from config if exists
         if allow_custom:
-            if self.window.config.has('cmd.prompt'):
-                prompt = self.window.config.get('cmd.prompt')
+            if self.window.core.config.has('cmd.prompt'):
+                prompt = self.window.core.config.get('cmd.prompt')
                 if prompt is not None and prompt != '':
                     cmd = prompt
 
@@ -98,10 +99,28 @@ class Command:
         try:
             chunks = response.split('~###~')
             for chunk in chunks:
-                try:
-                    cmds.append(json.loads(chunk.strip()))
-                except:
-                    pass
-        except:
+                cmd_dict = self.extract_cmd(chunk)
+                if cmd_dict is not None:
+                    cmds.append(cmd_dict)
+        except Exception as e:
+            # do nothing
             pass
-        return cmds
\ No newline at end of file
+        return cmds
+
+    def extract_cmd(self, chunk):
+        """
+        Extract command from response
+
+        :param chunk: chunk
+        :return: command json
+        :rtype: dict
+        """
+        cmd = None
+        chunk = chunk.strip()
+        if chunk and chunk.startswith('{') and chunk.endswith('}'):
+            try:
+                cmd = json.loads(chunk)
+            except json.JSONDecodeError as e:
+                # do nothing
+                pass
+        return cmd
