@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.18 01:20:00                  #
+# Updated Date: 2023.12.25 21:00:00                  #
 # ================================================== #
 
 import datetime
@@ -18,7 +18,7 @@ from openai import OpenAI
 class Image:
     DIRNAME = "img"
 
-    def __init__(self, window):
+    def __init__(self, window=None):
         """
         DALL-E Wrapper
 
@@ -30,6 +30,12 @@ class Image:
         """Initialize OpenAI API key"""
         pass
 
+    def install(self):
+        """Install provider data"""
+        img_dir = os.path.join(self.window.core.config.path, self.DIRNAME)
+        if not os.path.exists(img_dir):
+            os.mkdir(img_dir)
+
     def get_prompt(self, allow_custom=True):
         """
         Return image generate prompt command
@@ -46,13 +52,24 @@ class Image:
         '''
         # get custom prompt from config if exists
         if allow_custom:
-            if self.window.config.has('img_prompt'):
-                prompt = self.window.config.get('img_prompt')
+            if self.window.core.config.has('img_prompt'):
+                prompt = self.window.core.config.get('img_prompt')
                 if prompt is not None and prompt != '':
                     cmd = prompt
         return cmd
 
-    def generate(self, prompt, model="dall-e-3", num=None):
+    def get_client(self):
+        """
+        Return OpenAI client
+
+        :return: OpenAI client
+        """
+        return OpenAI(
+            api_key=self.window.core.config.get('api_key'),
+            organization=self.window.core.config.get('organization_key'),
+        )
+
+    def generate(self, prompt, model="dall-e-3", num=1):
         """
         Call DALL-E API
 
@@ -62,30 +79,27 @@ class Image:
         :return: images paths list
         :rtype: list
         """
-        if not self.window.config.get('img_raw'):
+        if not self.window.core.config.get('img_raw'):
             system_cmd = self.get_prompt()
             max_tokens = 200
             temperature = 1.0
             try:
                 # call GPT for generate best image generate prompt
-                response = self.window.app.gpt.quick_call(prompt, system_cmd, False, max_tokens,
-                                                      self.window.config.get('img_prompt_model'), temperature)
+                response = self.window.core.gpt.quick_call(prompt, system_cmd, False, max_tokens,
+                                                          self.window.core.config.get('img_prompt_model'), temperature)
                 if response is not None and response != "":
                     prompt = response
             except Exception as e:
+                self.window.core.debug.log(e)
                 print("Image prompt generate by model error: " + str(e))
 
         print("Generating image from: '{}'".format(prompt))
-
-        client = OpenAI(
-            api_key=self.window.config.get('api_key'),
-            organization=self.window.config.get('organization_key'),
-        )
+        client = self.get_client()
         response = client.images.generate(
             model=model,
             prompt=prompt,
             n=num,
-            size=self.window.config.get('img_resolution'),
+            size=self.window.core.config.get('img_resolution'),
         )
 
         # generate and download images
@@ -95,15 +109,36 @@ class Image:
                 break
             url = response.data[i].url
             res = requests.get(url)
+
+            # generate filename
             name = self.make_safe_filename(prompt) + "-" + datetime.date.today().strftime(
                 "%Y-%m-%d") + "_" + datetime.datetime.now().strftime("%H-%M-%S") + "-" + str(i + 1) + ".png"
-            path = os.path.join(self.window.config.path, self.DIRNAME, name)
+            path = os.path.join(self.window.core.config.path, self.DIRNAME, name)
+
             print("Downloading... [" + str(i + 1) + " of " + str(num) + "] to: " + path)
-            open(path, "wb").write(res.content)
-            paths.append(path)
+            # save image
+            if self.save_image(path, res.content):
+                paths.append(path)
 
         return paths, prompt
 
+    def save_image(self, path, image):
+        """
+        Save image to file
+
+        :param path: path to save
+        :param image: image data
+        :return: True if success
+        """
+        try:
+            with open(path, 'wb') as file:
+                file.write(image)
+            return True
+        except Exception as e:
+            self.window.core.debug.log(e)
+            print("Image save error: " + str(e))
+            return False
+
     def make_safe_filename(self, name):
         """
         Make safe filename
