@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.18 20:00:00                  #
+# Updated Date: 2023.12.26 16:00:00                  #
 # ================================================== #
 
 import json
@@ -14,12 +14,16 @@ import os
 import configparser
 import io
 
-from .config import Config
+from pygpt_net.config import Config
 
 
 class Locale:
     def __init__(self, domain=None):
-        """Locale handler"""
+        """
+        Locale handler
+
+        :param domain: translation domain
+        """
         self.config = Config()
         self.config.init(False)
         self.lang = 'en'
@@ -31,8 +35,10 @@ class Locale:
     def reload(self, domain=None):
         """
         Reload translations for domain
+
+        :param domain: translation domain
         """
-        self.config.load_config()
+        self.config.load(False)
         if self.config.has('lang'):
             self.lang = self.config.get('lang')
         self.load(self.lang, domain)
@@ -42,6 +48,7 @@ class Locale:
         Load translation ini file
 
         :param lang: language code
+        :param domain: translation domain
         """
         if type(lang) is not str:
             lang = 'en'
@@ -53,7 +60,7 @@ class Locale:
         path = os.path.join(self.config.get_user_path(), 'locale', locale_id + '.' + lang + '.ini')
         if not os.path.exists(path):
             # if not check if file exists in app data dir
-            path = os.path.join(self.config.get_root_path(), 'data', 'locale', locale_id + '.' + lang + '.ini')
+            path = os.path.join(self.config.get_app_path(), 'data', 'locale', locale_id + '.' + lang + '.ini')
         if not os.path.exists(path):
             print("FATAL ERROR: {} not found!".format(path))
             return None
@@ -71,6 +78,7 @@ class Locale:
         Return translation for key and domain
 
         :param key: translation key
+        :param domain: translation domain
         :return: translated string
         :rtype: str
         """
