@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.18 23:00:00                  #
+# Updated Date: 2023.12.26 16:00:00                  #
 # ================================================== #
 
 import copy
@@ -42,6 +42,7 @@ class Plugins:
 
         :param plugin: plugin instance
         """
+        plugin.attach(self.window)
         id = plugin.id
         self.plugins[id] = plugin
 
@@ -50,14 +51,23 @@ class Plugins:
             self.plugins[id].initial_options = copy.deepcopy(plugin.options)
 
         try:
-            plugins = self.window.config.get('plugins')
+            plugins = self.window.core.config.get('plugins')
             if id in plugins:
                 for key in plugins[id]:
                     if key in self.plugins[id].options:
                         self.plugins[id].options[key]['value'] = plugins[id][key]
         except Exception as e:
+            self.window.core.debug.log(e)
             print('Error while loading plugin options: {}'.format(id))
-            print(e)
+
+    def unregister(self, id):
+        """
+        Unregister plugin
+
+        :param id: plugin id
+        """
+        if self.is_registered(id):
+            self.plugins.pop(id)
 
     def restore_options(self, id):
         """
@@ -89,6 +99,7 @@ class Plugins:
         Dump locale
 
         :param plugin: plugin
+        :param path: path to locale file
         """
         options = {}
         options['plugin.name'] = plugin.name
@@ -120,6 +131,7 @@ class Plugins:
         Dump locale by id
 
         :param id: plugin id
+        :param path: path to locale file
         """
         if id in self.plugins:
             self.dump_locale(self.plugins[id], path)
@@ -132,6 +144,5 @@ class Plugins:
         for id in self.plugins:
             domain = 'plugin.' + id
             for lang in langs:
-                path = os.path.join(self.window.config.get_root_path(), 'data', 'locale', domain + '.' + lang + '.ini')
+                path = os.path.join(self.window.core.config.get_app_path(), 'data', 'locale', domain + '.' + lang + '.ini')
                 self.dump_locale(self.plugins[id], path)
-
